@@ -39,7 +39,7 @@ typedef struct _GFFGlyphInfo GFFGlyphInfo;
 
 #include <glib-object.h>
 #include <freetype/freetype.h>
-#include "gp-fontmap.h"
+#include "gnome-fontmap.h"
 #include "gnome-font.h"
 #include "gnome-rfont.h"
 
@@ -95,9 +95,9 @@ GnomeFont *gnome_font_face_get_font_full (GnomeFontFace *face, gdouble size, gdo
 
 /* Embeddable PostScript object */
 
-typedef struct _GFPSObject GFPSObject;
+typedef struct _GnomeFontPsObject GnomeFontPsObject;
 
-struct _GFPSObject {
+struct _GnomeFontPsObject {
 	/* Our face (NB referenced) */
 	GnomeFontFace *face;
 	/* Resident face name, if any */
@@ -119,11 +119,11 @@ struct _GFPSObject {
 	guchar *buf;
 };
 
-GFPSObject *gnome_font_face_pso_new (GnomeFontFace *face, guchar *residentname);
+GnomeFontPsObject *gnome_font_face_pso_new (GnomeFontFace *face, guchar *residentname);
 /* Mark glyph as used in internal bit array */
-void gnome_font_face_pso_mark_glyph (GFPSObject *pso, gint glyph);
-void gnome_font_face_pso_free (GFPSObject *pso);
-void gnome_font_face_pso_ensure_buffer (GFPSObject *pso);
+void gnome_font_face_pso_mark_glyph (GnomeFontPsObject *pso, gint glyph);
+void gnome_font_face_pso_free (GnomeFontPsObject *pso);
+void gnome_font_face_pso_ensure_buffer (GnomeFontPsObject *pso);
 
 /* Private face loader */
 
