@@ -177,6 +177,7 @@ fcpattern_to_gp_font_entry (FcPattern *font)
 	FcResult result;
 	FcChar8 *str;
 	int i;
+	gchar *c;
 
 	tt = g_new0 (GPFontEntryTT, 1);
 	e = (GPFontEntry *)tt;
@@ -203,8 +204,14 @@ fcpattern_to_gp_font_entry (FcPattern *font)
 
 	e->version = g_strdup ("1.0");
 
-	e->name = g_strdup_printf ("%s %s", e->familyname, e->weight);
+	e->name   = g_strdup_printf ("%s %s", e->familyname, e->weight);
 	e->psname = g_strdup_printf ("%s-%s", e->familyname, e->weight);
+	c = e->psname;
+	while (*c != '\0') {
+		if (*c == ' ')
+			*c = '_';
+		c++;
+	}
 
 	result = FcPatternGetInteger (font, FC_SLANT, 0, &i);
 	if (result == FcResultMatch)
@@ -221,6 +228,7 @@ static GPFontEntry *
 fcpattern_to_gp_font_entry_alias (FcPattern *font, const gchar *family, const gchar *style)
 {
 	GPFontEntry *e;
+	gchar *c;
 
 	e = fcpattern_to_gp_font_entry (font);
 
@@ -233,6 +241,13 @@ fcpattern_to_gp_font_entry_alias (FcPattern *font, const gchar *family, const gc
 	e->name = g_strdup_printf ("%s %s", family, style);
 	e->psname = g_strdup_printf ("%s-%s", family, style);
 
+	c = e->psname;
+	while (*c != '\0') {
+		if (*c == ' ')
+			*c = '_';
+		c++;
+	}
+
 	return e;
 }
 
@@ -416,56 +431,6 @@ gp_fontmap_load (void)
 	return map;
 }
 
-/* This is experimental method (not public anyways) (Lauris) */
-
-GPFontEntry *gp_font_entry_from_files (GPFontMap *map,
-				       const guchar *name, const guchar *family, const guchar *species, gboolean hidden,
-				       const guchar *filename, gint face, const GSList *additional)
-{
-	GPFontEntrySpecial *s;
-	const GSList *l;
-	gchar *p;
-
-	g_return_val_if_fail (map != NULL, NULL);
-	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (family != NULL, NULL);
-	g_return_val_if_fail (species != NULL, NULL);
-	g_return_val_if_fail (filename != NULL, NULL);
-
-	if (!hidden && g_hash_table_lookup (map->fontdict, name)) {
-		g_warning ("file %s: line %d: Font with name %s already exists", __FILE__, __LINE__, name);
-	}
-
-	s = g_new0 (GPFontEntrySpecial, 1);
-	s->entry.type = GP_FONT_ENTRY_SPECIAL;
-	s->entry.refcount = 1;
-	s->entry.face = NULL;
-	s->entry.name = g_strdup (name);
-
-	s->entry.version = g_strdup ("0.0");
-	s->entry.familyname = g_strdup (family);
-	s->entry.speciesname = g_strdup (species);
-	s->entry.psname = g_strdup ("Unnamed");
-
-	s->entry.weight = g_strdup ("Book");
-
-	s->file.name = g_strdup (filename);
-
-	for (l = additional; l != NULL; l = l->next) {
-		s->additional = g_slist_prepend (s->additional, g_strdup (l->data));
-	}
-	s->additional = g_slist_reverse (s->additional);
-
-	s->entry.Weight = gp_fontmap_lookup_weight (s->entry.weight);
-	p = strstr (s->entry.speciesname, "Italic");
-	if (!p) p = strstr (s->entry.speciesname, "Oblique");
-	s->entry.ItalicAngle = p ? -10.0 : 0.0;
-
-	s->subface = face;
-
-	return &s->entry;
-}
-
 /*
  * Font Entry stuff
  *
@@ -499,12 +464,18 @@ gp_font_entry_unref (GPFontEntry * entry)
 
 		g_return_if_fail (entry->face == NULL);
 
-		if (entry->name) g_free (entry->name);
-		if (entry->version) g_free (entry->version);
-		if (entry->familyname) g_free (entry->familyname);
-		if (entry->speciesname) g_free (entry->speciesname);
-		if (entry->psname) g_free (entry->psname);
-		if (entry->weight) g_free (entry->weight);
+		if (entry->name)
+			g_free (entry->name);
+		if (entry->version)
+			g_free (entry->version);
+		if (entry->familyname)
+			g_free (entry->familyname);
+		if (entry->speciesname)
+			g_free (entry->speciesname);
+		if (entry->psname)
+			g_free (entry->psname);
+		if (entry->weight)
+			g_free (entry->weight);
 
 		switch (entry->type) {
 		case GP_FONT_ENTRY_TYPE1_ALIAS:
@@ -560,7 +531,8 @@ gnome_font_list ()
 			map->fontlist = g_list_prepend (map->fontlist, e->name);
 		}
 		map->fontlist = g_list_reverse (map->fontlist);
-		if (!fontlist2map) fontlist2map = g_hash_table_new (NULL, NULL);
+		if (!fontlist2map)
+			fontlist2map = g_hash_table_new (NULL, NULL);
 		g_hash_table_insert (fontlist2map, map->fontlist, map);
 	}
 
@@ -628,6 +600,11 @@ gp_fe_sortname (gconstpointer a, gconstpointer b)
 static gint
 gp_fe_sortspecies (gconstpointer a, gconstpointer b)
 {
+	if (((GPFontEntry *)a)->speciesname == NULL)
+		return -1;
+	if (((GPFontEntry *)b)->speciesname == NULL)
+		return 1;
+	
 	return strcasecmp (((GPFontEntry *) a)->speciesname, ((GPFontEntry *) b)->speciesname);
 }
 
