@@ -1,9 +1,29 @@
-#define GP_GC_C
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
+ *  gp-gc.c: An opaque object, holding current drawing state
  *
- * Copyright (C) Lauris Kaplinski, 2000
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public License
+ *  as published by the Free Software Foundation; either version 2 of
+ *  the License, or (at your option) any later version.
  *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *
+ *  Copyright (C) 2000-2002 Ximian, Inc. and authors
+ *
+ */
+ 
+/*
  * TODO:
  *
  * - how is pen size calculated?
@@ -11,7 +31,9 @@
  *
  */
 
-#include <config.h>
+#define _GP_FONTMAP_C_
+
+#include "config.h"
 #include <math.h>
 #include <string.h>
 
@@ -28,9 +50,9 @@
 #include <libart_lgpl/art_vpath_svp.h>
 #include <libart_lgpl/art_svp_vpath_stroke.h>
 
-#include "gnome-font-compat.h"
 #include "gp-path.h"
 #include "gp-gc.h"
+#include "gp-gc-private.h"
 
 #define GP_GC_EPSILON 1e-18
 #define GP_GC_EQ(a,b) (fabs (a - b) < GP_GC_EPSILON)
@@ -591,30 +613,10 @@ gp_gc_moveto (GPGC * gc, gdouble x, gdouble y)
 	memcpy (a, ctx->ctm, 6 * sizeof (gdouble));
 	p.x = x;
 	p.y = y;
-#if 0
-	g_print ("ABC %g %g\n", p.x, p.y);
-	g_print ("ABD %g %g %g %g %g %g\n", ctx->ctm[0], ctx->ctm[1], ctx->ctm[2], ctx->ctm[3], ctx->ctm[4], ctx->ctm[5]);
-#endif
+
 	art_affine_point (&q, &p, a);
-#if 0
-	g_print ("ABE %g %g %g %g\n", q.x, q.y, p.x, p.y);
-#endif
 	ctx->currentpoint = q;
-#if 0
-	g_print ("ABF %g %g %g %g\n", ctx->currentpoint.x, ctx->currentpoint.y, q.x, q.y);
-	g_print ("ABG %g %g %g %g %g %g\n", ctx->ctm[0], ctx->ctm[1], ctx->ctm[2], ctx->ctm[3], ctx->ctm[4], ctx->ctm[5]);
-	g_print ("ABC %g %g\n", p.x, p.y);
-	g_print ("ABD %g %g %g %g %g %g\n", ctx->ctm[0], ctx->ctm[1], ctx->ctm[2], ctx->ctm[3], ctx->ctm[4], ctx->ctm[5]);
-#endif
-	art_affine_point (&q, &p, a);
-#if 0
-	g_print ("ABE %g %g %g %g\n", q.x, q.y, p.x, p.y);
-#endif
-	ctx->currentpoint = q;
-#if 0
-	g_print ("ABF %g %g %g %g\n", ctx->currentpoint.x, ctx->currentpoint.y, q.x, q.y);
-	g_print ("ABG %g %g %g %g %g %g\n", ctx->ctm[0], ctx->ctm[1], ctx->ctm[2], ctx->ctm[3], ctx->ctm[4], ctx->ctm[5]);
-#endif
+
 	gp_path_moveto (ctx->currentpath, ctx->currentpoint.x, ctx->currentpoint.y);
 
 	return 0;
@@ -908,6 +910,7 @@ gp_ctx_new (void)
 	ctx->line_flag = GP_GC_FLAG_UNSET;
 	ctx->dash.n_dash = 0;
 	ctx->dash.dash = NULL;
+	ctx->dash.offset = 0;
 	ctx->dash_flag = GP_GC_FLAG_UNSET;
 	ctx->privatedash = FALSE;
 
