@@ -267,7 +267,7 @@ gpa_model_new_from_info_tree (xmlNodePtr tree)
 	}
 	
 	/* Check for model file */
-	model_file = g_strdup_printf (DATADIR "/gnome-print-2.0/models/%s.model", model_id);
+	model_file = g_strdup_printf (GNOME_PRINT_DATA_DIR "/models/%s.model", model_id);
 	if (!g_file_test (model_file, G_FILE_TEST_IS_REGULAR)) {
 		g_warning ("Model description file is missing %s", model_id);
 		xmlFree (model_id);
@@ -488,7 +488,7 @@ gpa_model_get_by_id (const guchar *id)
 		return GPA_NODE (model);
 	}
 
-	path = g_strdup_printf (DATADIR "/gnome-print-2.0/models/%s.model", id);
+	path = g_strdup_printf (GNOME_PRINT_DATA_DIR "/models/%s.model", id);
 	if (!g_file_test (path, G_FILE_TEST_IS_REGULAR)) {
 		g_warning ("Could not get model by id '%s' from '%s'\n", id, path);
 		g_free (path);
@@ -531,7 +531,7 @@ gpa_model_load (GPAModel *model)
 	if (model->loaded)
 		return TRUE;
 
-	path = g_strdup_printf (DATADIR "/gnome-print-2.0/models/%s.model", GPA_NODE_ID (model));
+	path = g_strdup_printf (GNOME_PRINT_DATA_DIR "/models/%s.model", GPA_NODE_ID (model));
 	if (!g_file_test (path, G_FILE_TEST_IS_REGULAR)) {
 		g_warning ("Model description file missing %s", GPA_NODE_ID (model));
 		g_free (path);
